unit DAVSLEvents_Events;
{-----------------------------------------------------------
Demo of DAVSL VSL Framework
www.diagramantics.com

Demonstrates a VSL which monitors events and reports them to a
VSL window.

This unit demos the critical TVisioAddOnSink object that the VSL passes
to Visio (see TEventController.EnableEventMonitoring).
Also note the initialization section, and the DAVSL_IncludeEvents.pas unit.

2000-09-20 GW
------------------------------------------------------------}
interface
uses ComObj, ActiveX, Visio_TLB, DAVisioAddOnSink_TLB;
Type
  //----------------------------------------------------
  TVisioAddOnSink = class(TAutoObject, IVisioAddOnSink)
  //----------------------------------------------------
  private
    FRefCount: Integer;
    OurTypeInfo: ITypeInfo;
  public
    constructor Create;

    //---------------------------------
    // VisEventProc part of IVisEventProc
    //---------------------------------
    procedure VisEventProc(
                        Event: Smallint;
                 const Source: IUnknown;
                           ID: integer;
                          Seq: Integer;
                const Subject: IUnknown;
                        Extra: OleVariant
                        ); safecall;
  end;

Const
  visConnAdd = visEvtConnect + visEvtAdd;
  visConnDel = visEvtConnect + visEvtDel;

implementation
uses windows, sysutils, comserv, DAVSLEvents_Control;

//---------------------------------------------------
constructor TVisioAddOnSink.Create;
//---------------------------------------------------
Var
  hr: HRESULT;
  TypeLib: ITypeLib;
begin
  inherited;
  FRefCount := 0;
  hr := NOERROR;

  hr := LoadRegTypeLib(LIBID_Visio, 4, 7, {LOCALE_NEUTRAL} 0, TypeLib);

  if SUCCEEDED(hr) then
  Begin
    hr := TypeLib.GetTypeInfoOfGuid(IID_IVisEventProc, OurTypeInfo);
  end;
  hr := 0;
end;

//------------------------------------------------------------------
procedure  TVisioAddOnSink.VisEventProc(
//------------------------------------------------------------------
          Event   : Smallint;
    const Source  : IUnknown;
          ID      : integer;
          Seq     : Integer;
    const Subject : IUnknown;
          Extra   : OleVariant
          );
Var
  EventWord: word;
  S: string;
  FromShape, ToShape: Visio_TLB.Shape;
  AConnects: Visio_TLB.Connects;
  AConnect: Visio_TLB.Connect;

Label skip;
Begin
  try
    EventWord := Event;
    //-----------------------------------------------------
    // Direct event notifications to whatever
    // object needs to know. Take this opportunity to
    // repackage generic VisEventProc arguments into typed
    // params so that receiving object has easier time
    //----------------------------------------------------

    Case EventWord of
      visConnAdd, visConnDel: Begin
        AConnects := Subject as Visio_TLB.Connects;
        EventController.OnConnAddDel(AConnects, EventWord);
      end;
      // other cases...
      else Begin
        // handle unexpected cases if any
      end;
    end;
  except
    // fail silently, not always the best policy!
  end;
end;

initialization
  TAutoObjectFactory.Create(ComServer, TVisioAddOnSink, Class_VisioAddOnSink, ciInternal, tmSingle);

end.

