unit DAVSLShapeChange_AddOns;
{-----------------------------------------------------------
Demo of DAVSL VSL Framework
www.diagramantics.com

Demonstrates AddOns which make use of several arguments with values which
are strings to be translated to integers. Note use of TArgInfo and TValInfo
to do this.

Revision History
----------------
2000-09-18 GW
------------------------------------------------------------}

//========================================
               interface
//========================================

// Nothing absolutely needs to be exposed

//========================================
             implementation
//========================================
uses SysUtils, classes, Visio_TLB, DAVAO, DAVSL, DAVSL_Util, DAVSLShapeChange_Control;

Type
  //------------------------------
  TAddOnShapeChange_Color = class(TAddOn)
  //------------------------------
    constructor Create;
    function vlm_RUN(V2LRec: PVAOV2LRecord; Args: TStringList): TVAORC; override;
  end;

  //------------------------------
  TAddOnShapeChange_Angle = class(TAddOn)
  //------------------------------
    constructor Create;
    function vlm_RUN(V2LRec: PVAOV2LRecord; Args: TStringList): TVAORC; override;
  end;

Var
  AddOnShapeChange_Color: TAddOnShapeChange_Color;
  AddOnShapeChange_Angle: TAddOnShapeChange_Angle;

//------------------------------
// AddOn Description .
//------------------------------

Const
  FillForegndKW = 'FILLFOREGND';
  LineColorKW   = 'LINECOLOR';
  AngleKW       = 'ANGLE';
//------------------------------------------------------
constructor TAddOnShapeChange_Color.Create;
//------------------------------------------------------
Var
  AI: TArgInfo;
  VI: TValInfo;
begin
  inherited Create(
    VAO_AOATTS_ISACTION OR VAO_AOATTS_HASABOUT, // atts
    VAO_ENABLEALWAYS     , // enabMask
    0                    , // invokeOnMask
    0                    , // notifyOnMask
    'DAVSLShapeChange_Color'  , // lpName
    'Demo addon that accepts arguments and changes color'
  );

  AI := Info.AddArgInfo(FillForegndKW, 1, 'Name of color for fill', false, 2);
  VI := AI.AddValInfo('RED'  , 2, 'Red color');
  VI := AI.AddValInfo('GREEN', 3, 'Green color');
  VI := AI.AddValInfo('BLUE' , 4, 'Blue color');

  AI := Info.AddArgInfo(LineColorKW , 2, 'Name of color for line', false, 4);
  VI := AI.AddValInfo('RED'  , 2, 'Red color');
  VI := AI.AddValInfo('GREEN', 3, 'Green color');
  VI := AI.AddValInfo('BLUE' , 4, 'Blue color');
end;

//------------------------------------------------------
function TAddOnShapeChange_Color.vlm_RUN(V2LRec: PVAOV2LRecord; Args: TStringList): TVAORC;
//------------------------------------------------------
Var
  AShape: Visio_TLB.Shape;
  AWin: Visio_TLB.Window;
  S: string;
  LineColor, FillForegnd: integer;
begin
  try
    //------------------------------------
    // Set up arguments for "controller"
    //------------------------------------
    AWin := VSL.visApp.ActiveWindow;
    if not Assigned(AWin) then Raise Exception.Create('No active window');
    If AWin.Selection.Count <> 1 then Raise Exception.Create('Please select exactly one shape.');
    AShape := AWin.Selection[1];

    S := Args.Values[FillForegndKW];
    FillForegnd := Info.GetArgInfo(FillForegndKW).LookupVal(S);

    S := Args.Values[LineColorKW];
    LineColor := Info.GetArgInfo(LineColorKW).LookupVal(S);

    ShapeChange_Controller.ColorChange(AShape, FillForegnd, LineColor);
  except
    on E: Exception do ErrorMessage('Error: ' + E.Message);
  end;
end;

{ TAddOnShapeChange_Angle }

//------------------------------------------------------
constructor TAddOnShapeChange_Angle.Create;
//------------------------------------------------------
Var
  AI: TArgInfo;
begin
  inherited Create(
    VAO_AOATTS_ISACTION OR VAO_AOATTS_HASABOUT , // atts
    VAO_ENABLEALWAYS     , // enabMask
    0                    , // invokeOnMask
    0                    , // notifyOnMask
    'DAVSLShapeChange_Angle'  , // lpName
    'Demo addon that accepts arguments and changes angle'
  );

  AI := Info.AddArgInfo(AngleKW, 1, 'Angle in degrees, integer', false, 45);
end;

//------------------------------------------------------
function TAddOnShapeChange_Angle.vlm_RUN(V2LRec: PVAOV2LRecord; Args: TStringList): TVAORC;
//------------------------------------------------------
Var
  AShape: Visio_TLB.Shape;
  AWin: Visio_TLB.Window;
  S: string;
  Angle, DefaultAngle: integer;
  AI: TArgInfo;
begin
  try
    //------------------------------------
    // Set up arguments for "controller"
    //------------------------------------
    AWin := VSL.visApp.ActiveWindow;
    if not Assigned(AWin) then Raise Exception.Create('No active window');
    If AWin.Selection.Count <> 1 then Raise Exception.Create('Please select exactly one shape.');
    AShape := AWin.Selection[1];

    S := Args.Values[AngleKW];
    AI := Info.GetArgInfo(AngleKW);
    DefaultAngle := AI.DefaultVal;
    Angle := StrToIntDef(S, DefaultAngle);
    ShapeChange_Controller.AngleChange(AShape, Angle);
  except
    on E: Exception do ErrorMessage('Error: ' + E.Message);
  end;
end;

initialization
  //-------------------------------------------------------------
  // Creates object for this AddOn, and Enlists it with GWVAO_Mgr
  //-------------------------------------------------------------
  AddOnShapeChange_Color := TAddOnShapeChange_Color.Create;
  AddOnShapeChange_Angle := TAddOnShapeChange_Angle.Create;
end.

